pub async fn download_info(relay: &str, name: &str) -> Result<TransferResponse>
Fetches download information from the relay server for the given file name.

Arguments

  • relay - The URL of the relay server.
  • name - The name of the file.

Returns

A future that resolves to a Result containing the download information if the request is successful, or an error if the request fails.