pub async fn download_success(relay: &str, name: &str) -> Result<()>
Notifies the relay server that the file download was successful for the given file name.

Arguments

  • relay - The URL of the relay server.
  • name - The name of the file.

Returns

A future that resolves to a Result containing Ok(()) if the request is successful, or an error if the request fails.